as.binaryMatrix: Convert a family of sets from set to matrix representation

View source: R/as.binaryMatrix.R

as.binaryMatrixR Documentation

Convert a family of sets from set to matrix representation

Description

Convert a family of sets from set to matrix representation

Usage

as.binaryMatrix(x)

Arguments

x

Set object

Value

Matrix object

See Also

Other Utilities: as.famset()

Examples

m <- matrix(c(1,0,0,0,
              0,1,0,0,
              1,0,1,0,
              0,1,1,0,
              1,1,1,1), ncol=4, byrow=TRUE)
m
as.binaryMatrix(as.famset(m))


kstIO documentation built on Sept. 7, 2026, 9:06 a.m.