as.famset: Convert a family of sets from matrix to set representation

View source: R/as.famset.R

as.famsetR Documentation

Convert a family of sets from matrix to set representation

Description

Convert a family of sets from matrix to set representation

Usage

as.famset(m, as.letters = TRUE)

Arguments

m

Binary matrix

as.letters

What to do if is.nuill(colnames(x)). Defaults to TRUE.

Value

Set object

If colnames(x) is set, the colnames are used as item identifiers for the set. Otherwise, letters or numbers are used, depending on the as.letters parameter.

See Also

Other Utilities: as.binaryMatrix()

Examples

m <- matrix(c(1,0,0,0,
              0,1,0,0,
              1,0,1,0,
              0,1,1,0,
              1,1,1,1), ncol=4, byrow=TRUE)
m
as.famset(m)



kstIO documentation built on Sept. 7, 2026, 9:06 a.m.