| read_kstructure | R Documentation |
Read a knowledge structure from file
read_kstructure(
filename,
format = "auto",
as.letters = TRUE,
header = TRUE,
sep = ",",
enforce = TRUE
)
filename |
Name of the file |
format |
File format (default "auto") |
as.letters |
How to name items (default TRUE) |
header |
For spreadsheet files: does it include a header line (default TRUE) |
sep |
Cell separator for CSV files (default ',') |
enforce |
Do we enforce knowledge structure properties (default TRUE)? |
List with two elements matrix and sets containing the respective representations of the knowledge structure read
Other Functions for reading and writing families of sets:
read_kbase(),
read_kdata(),
read_kfamset(),
read_kspace(),
write_kbase(),
write_kdata(),
write_kfamset(),
write_kspace(),
write_kstructure()
kstMatrix::xpl$space
tempfile <- paste0(tempdir(), "/test.struc")
write_kstructure(kstMatrix::xpl$space, tempfile, format="SRBT")
read_kstructure(tempfile)
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.