write_kbase: Write a base file

write_kbaseR Documentation

Write a base file

Description

Write a base to a file. The file formats are described in the kstIO-package information page.

Usage

  write_kbase(x, 
              filename, 
              format = NULL,
              sep = ',')

Arguments

x

The data to be written, either a binary matrix or an object of kbase class.

filename

A character string specifying the name of the base file.

format

Specification of the files format. Can be "SRBT", "KST", "CSV", "matrix" or sprreadsheet formats.

sep

Cell separator for CSV files.

Author(s)

Cord Hockemeyer cord.hockemeyer@uni-graz.at

References

Hockemeyer, C. (2001). KST Tools User Manual (2nd ed.). https://resources.cord-hockemeyer.info/techreports/KST-Tools_TechRep_FWF01.pdf.

Poetzi, S. & Wesiak, G. (2001). SRbT Tools User Manual. https://resources.cord-hockemeyer.info/techreports/SRBT-Tools_TechRep_FWF01.pdf

See Also

kbase, kstIO-package

Examples

d <- getwd()
setwd(tempdir())
# Write base to file
write_kbase(phsg$basis, "phsg.bas") # Write in SRBT format
write_kbase(phsg$basis, "phsg.xlsx") # XLSX format
setwd(d)

kstIO documentation built on March 8, 2026, 5:06 p.m.