| write_kdata | R Documentation |
Write a data set to file
write_kdata(x, filename, format = NULL, sep = ",")
x |
Data set (only in matrix ( |
filename |
Name of the file to be written |
format |
File format |
sep |
Cell separator for CSV files If the file format is not specified, |
Other Functions for reading and writing families of sets:
read_kbase(),
read_kdata(),
read_kfamset(),
read_kspace(),
read_kstructure(),
write_kbase(),
write_kfamset(),
write_kspace(),
write_kstructure()
head(kstMatrix::xpl$data)
tempfile <- paste0(tempdir(), "/testdata.csv")
write_kdata(kstMatrix::xpl$data, tempfile)
cat(head(readLines(tempfile)), sep='\n')
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.