write_kfamset: Write a family f sets to file

write_kfamsetR Documentation

Write a family f sets to file

Description

Write a family f sets to file

Usage

write_kfamset(x, filename, format = NULL, sep = ",", enforce = TRUE)

Arguments

x

Family of sets (in set (kfamset) or matrix (kmfamset) format)

filename

Name of the file to be written

format

File format

sep

Cell separator for CSV files

enforce

Should knowledge structure properties be enforced (only for matrix form)?

If the file format is not specified, write_kfamset() looks at the filename extension. If it is some spreadsheet type (CSV, ODS, or XLSX), the respective file format is chosen, otherwise SRBT is selected.

For larger families of sets, it might be better suitable and way more efficient to save and later load them with the save() and load() functions - if they are to be used only with R.

See Also

Other Functions for reading and writing families of sets: read_kbase(), read_kdata(), read_kfamset(), read_kspace(), read_kstructure(), write_kbase(), write_kdata(), write_kspace(), write_kstructure()

Examples

kstMatrix::xpl$basis
tempfile <- paste0(tempdir(), "/test.bas")
write_kbase(kstMatrix::xpl$basis, tempfile, format="KST")
cat(readLines(tempfile), sep='\n')


kstIO documentation built on Sept. 7, 2026, 9:06 a.m.