write_kspace: Write a knowledge space to file

write_kspaceR Documentation

Write a knowledge space to file

Description

Write a knowledge space to file

Usage

write_kspace(x, filename, format = NULL, sep = ",", enforce = TRUE)

Arguments

x

Knowledge space (in set (kspace) or matrix (kmspace) format)

filename

Name of the file to be written

format

File format

sep

Cell separator for CSV files

enforce

Should knowledge space properties be enforced (only for matrix form)?

If the file format is not specified, write_kspace() looks at the filename extension. If it is some spreadsheet type (CSV, ODS, or XLSX), the respective file format is chosen, otherwise SRBT is selected.

For larger knowledge spaces, it might be better suitable and way more efficient to save and later load them with the save() and load() functions - if they are to be used only with R.

See Also

Other Functions for reading and writing families of sets: read_kbase(), read_kdata(), read_kfamset(), read_kspace(), read_kstructure(), write_kbase(), write_kdata(), write_kfamset(), write_kstructure()

Examples

kstMatrix::xpl$space
tempfile <- paste0(tempdir(), "/test.spc")
write_kspace(kstMatrix::xpl$space, tempfile, format="matrix")
cat(readLines(tempfile), sep='\n')
# Using a non-space object
write_kspace(kstMatrix::xpl$basis, tempfile, format="matrix")
cat(readLines(tempfile), sep='\n')



kstIO documentation built on Sept. 7, 2026, 9:06 a.m.