write_surmisefunction: Write a surmise function to file

write_surmisefunctionR Documentation

Write a surmise function to file

Description

Write a surmise function to file

Write a attribution function to file

Usage

write_surmisefunction(x, filename, sep = ",")

write_attributionfunction(x, filename, sep = ",")

Arguments

x

Attribute function (kmattributionfunction object))

filename

Name of the file to be written

sep

Cell separator for CSV files

Attribute functions can only be stored in spreadsheet format. The concrete file format (CSV, ODS, or XLSX) is selected based on the filename extension.

See Also

Other Functions for reading and writing surmise and attribution functions and relations: read_surmisefunction(), read_surmiserelation(), write_surmiserelation()

Examples

kstMatrix::xpl$sf
tempfile <- paste0(tempdir(), "/test_sf.csv")
write_surmisefunction(kstMatrix::xpl$sf, tempfile)
cat(readLines(tempfile), sep='\n')


kstIO documentation built on Sept. 7, 2026, 9:06 a.m.