| write_surmiserelation | R Documentation |
Write a surmise function to file
Write an attribution function to file
write_surmiserelation(x, filename, format = NULL, sep = ",")
write_attributionrelation(x, filename, format = NULL, sep = ",")
x |
Attribution relation ( |
filename |
Name of the file to be written |
format |
File format |
sep |
Cell separator for CSV files Attribution relations are available only in matrix format. If |
Other Functions for reading and writing surmise and attribution functions and relations:
read_surmisefunction(),
read_surmiserelation(),
write_surmisefunction()
kstMatrix::xpl$sr
tempfile <- paste0(tempdir(), "/test_sf.csv")
write_surmiserelation(kstMatrix::xpl$sr, tempfile)
cat(readLines(tempfile), sep='\n')
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.