| as.famset | R Documentation |
Convert a family of sets from matrix to set representation
as.famset(m, as.letters = TRUE)
m |
Binary matrix |
as.letters |
What to do if |
Set object
If colnames(x) is set, the colnames are used as item identifiers
for the set. Otherwise, letters or numbers are used, depending on the
as.letters parameter.
Other Utilities:
as.binaryMatrix()
m <- matrix(c(1,0,0,0,
0,1,0,0,
1,0,1,0,
0,1,1,0,
1,1,1,1), ncol=4, byrow=TRUE)
m
as.famset(m)
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.