| read_kbase | R Documentation |
Read a basis from file
read_kbase(
filename,
format = "auto",
as.letters = TRUE,
header = TRUE,
sep = ",",
enforce = TRUE
)
filename |
Name of the basis file |
format |
File format (default "auto") |
as.letters |
How to name items (default TRUE) |
header |
For spreadsheet files: does it include a header line (default TRUE) |
sep |
Cell separator for CSV files (default ',') |
enforce |
Do we enforce basis properties (default TRUE)? |
List with two elements matrix and sets containing the respective representations of the basis read
Please note that the terms 'base' and 'basis' are used synonymously and interchangeably.
Other Functions for reading and writing families of sets:
read_kdata(),
read_kfamset(),
read_kspace(),
read_kstructure(),
write_kbase(),
write_kdata(),
write_kfamset(),
write_kspace(),
write_kstructure()
kstMatrix::xpl$basis
tempfile <- paste0(tempdir(), "/test.bas")
write_kbase(kstMatrix::xpl$basis, tempfile, format="SRBT")
read_kbase(tempfile)
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.