| read_kspace | R Documentation |
Read a knowledge space from file
read_kspace(
filename,
format = "auto",
as.letters = TRUE,
header = TRUE,
sep = ",",
enforce = TRUE
)
filename |
Name of the file |
format |
File format (default "auto") |
as.letters |
How to name items (default TRUE) |
header |
For spreadsheet files: does it include a header line (default TRUE) |
sep |
Cell separator for CSV files (default ',') |
enforce |
Do we enforce knowledge space properties (default TRUE)? |
List with two elements matrix and sets containing the respective representations of the knowledge space read
Please note that enforcing knowledge space properties (i.e. computing the closure under union) is computationally complex and therefore may take quite some time.
Other Functions for reading and writing families of sets:
read_kbase(),
read_kdata(),
read_kfamset(),
read_kstructure(),
write_kbase(),
write_kdata(),
write_kfamset(),
write_kspace(),
write_kstructure()
kstMatrix::xpl$space
tempfile <- paste0(tempdir(), "/test.spc")
write_kspace(kstMatrix::xpl$space, tempfile, format="SRBT")
read_kspace(tempfile)
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.