| read_surmisefunction | R Documentation |
Read a surmise function from file
Read an attribution function from file
read_surmisefunction(filename, sep = ",", enforce = TRUE)
readattributionfunction(filename, sep = ",")
filename |
Name of the file |
sep |
Cell separator for CSV files (default ','). |
enforce |
Do we enforce surmise function properties (default TRUE)? |
kmsurmisefunction object
Surmise and attribution functions can only be stored in spreadsheet files. The exact file type (CSV, ODS, or XLSX) is automatically inferred from the filename extension.
kmsurmisefunction object
Surmise and attribution functions can only be stored in spreadsheet files. The exact file type (CSV, ODS, or XLSX) is automatically inferred from the filename extension.
Other Functions for reading and writing surmise and attribution functions and relations:
read_surmiserelation(),
write_surmisefunction(),
write_surmiserelation()
kstMatrix::xpl$sf
tempfile <- paste0(tempdir(), "/test_sf.csv")
write_surmisefunction(kstMatrix::xpl$sf, tempfile)
cat(readLines(tempfile), sep='\n')
read_surmisefunction(tempfile)
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.