read_surmisefunction: Read surmise function file

read_surmisefunctionR Documentation

Read surmise function file

Description

Read a surmise function from a file. The file formats are described in the kstIO-package information page.

Usage

  read_surmisefunction(filename)

Arguments

filename

A character string specifying the name of the surmise function file.

Details

Surmise function files exist (so far) only in spreadsheet format. The concrete file type is derived from the filname extension.

Value

A data frame containing the surmise function.

Author(s)

Cord Hockemeyer cord.hockemeyer@uni-graz.at

See Also

kstIO-package

Examples

d <- getwd()
setwd(tempdir())
sf <- kmsurmisefunction(phsg$basis)
write_surmisefunction(sf, "phsg_sf.xlsx")
read_surmisefunction("phsg_sf.xlsx")
setwd(d)

kstIO documentation built on March 8, 2026, 5:06 p.m.