| read_surmisefunction | R Documentation |
Read a surmise function from a file. The file formats are described in the kstIO-package information page.
read_surmisefunction(filename)
filename |
A character string specifying the name of the surmise function file. |
Surmise function files exist (so far) only in spreadsheet format. The concrete file type is derived from the filname extension.
A data frame containing the surmise function.
Cord Hockemeyer cord.hockemeyer@uni-graz.at
kstIO-package
d <- getwd()
setwd(tempdir())
sf <- kmsurmisefunction(phsg$basis)
write_surmisefunction(sf, "phsg_sf.xlsx")
read_surmisefunction("phsg_sf.xlsx")
setwd(d)
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.