| write_kbase | R Documentation |
Write a base to a file. The file formats are described in the kstIO-package information page.
write_kbase(x,
filename,
format = NULL,
sep = ',')
x |
The data to be written, either a binary matrix or an object
of |
filename |
A character string specifying the name of the base file. |
format |
Specification of the files format. Can be "SRBT", "KST", "CSV", "matrix" or sprreadsheet formats. |
sep |
Cell separator for CSV files. |
Cord Hockemeyer cord.hockemeyer@uni-graz.at
Hockemeyer, C. (2001). KST Tools User Manual (2nd ed.). https://resources.cord-hockemeyer.info/techreports/KST-Tools_TechRep_FWF01.pdf.
Poetzi, S. & Wesiak, G. (2001). SRbT Tools User Manual. https://resources.cord-hockemeyer.info/techreports/SRBT-Tools_TechRep_FWF01.pdf
kbase,
kstIO-package
d <- getwd()
setwd(tempdir())
# Write base to file
write_kbase(phsg$basis, "phsg.bas") # Write in SRBT format
write_kbase(phsg$basis, "phsg.xlsx") # XLSX format
setwd(d)
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.