write_kdata: Write a knowledge space theory file

write_kdataR Documentation

Write a knowledge space theory file

Description

Write a data set to a file. The file formats are described in the kstIO-package information page.

Usage

  write_kdata(x, 
              filename, 
              format = NULL,
              sep = ',')

Arguments

x

The data to be written, as a binary matrix.

filename

A character string specifying the name of the data file.

format

Specification of the files format. Can be "KST" or spreadsheet format.

]

sep

Cell separator for CSV format.

Author(s)

Cord Hockemeyer cord.hockemeyer@uni-graz.at

References

Hockemeyer, C. (2001). KST Tools User Manual (2nd ed.). https://resources.cord-hockemeyer.info/techreports/KST-Tools_TechRep_FWF01.pdf.

Poetzi, S. & Wesiak, G. (2001). SRbT Tools User Manual. https://resources.cord-hockemeyer.info/techreports/SRBT-Tools_TechRep_FWF01.pdf

See Also

kstIO-package

Examples

d <- getwd()
setwd(tempdir())
space <- kmunionclosure(phsg$basis)
df <- kmsimulate(space, 100, 0.1, 0.05)
# Write data to file
write_kdata(df, "phsg.dat") # Write in KST format
write_kdata(df, "phsg_dat.xlsx") # xlsx format
setwd(d)

kstIO documentation built on March 8, 2026, 5:06 p.m.