| write_kfamset | R Documentation |
Write a family f sets to file
write_kfamset(x, filename, format = NULL, sep = ",", enforce = TRUE)
x |
Family of sets (in set ( |
filename |
Name of the file to be written |
format |
File format |
sep |
Cell separator for CSV files |
enforce |
Should knowledge structure properties be enforced (only for matrix form)? If the file format is not specified, For larger families of sets, it might be better suitable and way more
efficient to save and later load them with the |
Other Functions for reading and writing families of sets:
read_kbase(),
read_kdata(),
read_kfamset(),
read_kspace(),
read_kstructure(),
write_kbase(),
write_kdata(),
write_kspace(),
write_kstructure()
kstMatrix::xpl$basis
tempfile <- paste0(tempdir(), "/test.bas")
write_kbase(kstMatrix::xpl$basis, tempfile, format="KST")
cat(readLines(tempfile), sep='\n')
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.