write_kfamset: Write a family of sets to a file

write_kfamsetR Documentation

Write a family of sets to a file

Description

Write a family of sets to a file. The file formats are described in the kstIO-package information page.

Usage

  write_kfamset(x, 
                filename, 
                format = NULL, 
                sep = ',')

Arguments

x

The data to be written, either a binary matrix as kmfamset object or an object of kfamset class.

filename

A character string specifying the name of the famset file.

format

Specification of the files format. Can be "KST", matrix, "CSV", "ODS", or "XLSX".

sep

Cell eparator for CSV files.

Details

The format values refer to the different generations of file formats described in kstIO-package.

Author(s)

Cord Hockemeyer cord.hockemeyer@uni-graz.at

References

Hockemeyer, C. (2001). KST Tools User Manual (2nd ed.). https://resources.cord-hockemeyer.info/techreports/KST-Tools_TechRep_FWF01.pdf.

Poetzi, S. & Wesiak, G. (2001). SRbT Tools User Manual. https://resources.cord-hockemeyer.info/techreports/SRBT-Tools_TechRep_FWF01.pdf

See Also

kstIO-package

Examples

# Obtain data to write from the 'pks' package
d <- getwd()
setwd(tempdir())
# Write famset to file
write_kfamset(phsg$basis, "phsg.fs") # Write in KST format
write_kfamset(phsg$basis, "phsg.ods") # Write the matrix in ODS format
setwd(d)

kstIO documentation built on March 8, 2026, 5:06 p.m.