| write_kfamset | R Documentation |
Write a family of sets to a file. The file formats are described in the kstIO-package information page.
write_kfamset(x,
filename,
format = NULL,
sep = ',')
x |
The data to be written, either a binary matrix as |
filename |
A character string specifying the name of the famset file. |
format |
Specification of the files format. Can be "KST", matrix, "CSV", "ODS", or "XLSX". |
sep |
Cell eparator for CSV files. |
The format values refer to the different generations of file formats
described in kstIO-package.
Cord Hockemeyer cord.hockemeyer@uni-graz.at
Hockemeyer, C. (2001). KST Tools User Manual (2nd ed.). https://resources.cord-hockemeyer.info/techreports/KST-Tools_TechRep_FWF01.pdf.
Poetzi, S. & Wesiak, G. (2001). SRbT Tools User Manual. https://resources.cord-hockemeyer.info/techreports/SRBT-Tools_TechRep_FWF01.pdf
kstIO-package
# Obtain data to write from the 'pks' package
d <- getwd()
setwd(tempdir())
# Write famset to file
write_kfamset(phsg$basis, "phsg.fs") # Write in KST format
write_kfamset(phsg$basis, "phsg.ods") # Write the matrix in ODS format
setwd(d)
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.