| write_kstructure | R Documentation |
Write a knowledge structure to file
write_kstructure(x, filename, format = NULL, sep = ",", enforce = TRUE)
x |
Knowledge space (in set ( |
filename |
Name of the file to be written |
format |
File format |
sep |
Cell separator for CSV files |
enforce |
Should knowledge structure properties be enforced (only for matrix form)? If the file format is not specified, For larger knowledge structures, it might be better suitable and way more
efficient to save and later load them with the |
Other Functions for reading and writing families of sets:
read_kbase(),
read_kdata(),
read_kfamset(),
read_kspace(),
read_kstructure(),
write_kbase(),
write_kdata(),
write_kfamset(),
write_kspace()
kstMatrix::xpl$space
tempfile <- paste0(tempdir(), "/test.struc")
write_kstructure(kstMatrix::xpl$space, tempfile, format="matrix")
cat(readLines(tempfile), sep='\n')
# Enforcing knowledge structure properties for a non-structure object
write_kstructure(kstMatrix::xpl$basis, tempfile, format="SRBT")
cat(readLines(tempfile), sep='\n')
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.