write_kstructure: Write a knowledge structure file

write_kstructureR Documentation

Write a knowledge structure file

Description

Write a knowledge structure to a file. The file formats are described in the kstIO-package information page.

Usage

  write_kstructure(x, filename, format = NULL, sep=',')

Arguments

x

The data to be written, either a binary matrix or an object of kstructure class.

filename

A character string specifying the name of the base file.

format

Specification of the files format. Can be "SRBT" (default), "KST", "matrix", or spreadsheet formats. Default is NULL

sep

Cell separator for CSV files - otherwise ignored.

Details

The format values refer to the different generations of file formats described in kstIO-package.

Author(s)

Cord Hockemeyer cord.hockemeyer@uni-graz.at

References

Hockemeyer, C. (2001). KST Tools User Manual (2nd ed.). https://resources.cord-hockemeyer.info/techreports/KST-Tools_TechRep_FWF01.pdf.

Poetzi, S. & Wesiak, G. (2001). SRbT Tools User Manual. https://resources.cord-hockemeyer.info/techreports/SRBT-Tools_TechRep_FWF01.pdf

See Also

kstructure, kstIO-package

Examples

# Obtain data to write from the 'pks' package
d <- getwd()
setwd(tempdir())
kst <-kmunionclosure(phsg$basis)
# Write structure to file
write_kstructure(kst, "phsg.struct") # Write in (default) SRBT format
# Write the matrix in CSV format
write_kstructure(kst, "phsg.csv") 
setwd(d)

kstIO documentation built on March 8, 2026, 5:06 p.m.