| write_kstructure | R Documentation |
Write a knowledge structure to a file. The file formats are described in the kstIO-package information page.
write_kstructure(x, filename, format = NULL, sep=',')
x |
The data to be written, either a binary matrix or an object
of |
filename |
A character string specifying the name of the base file. |
format |
Specification of the files format. Can be "SRBT" (default), "KST", "matrix", or spreadsheet formats. Default is NULL |
sep |
Cell separator for CSV files - otherwise ignored. |
The format values refer to the different generations of file formats
described in kstIO-package.
Cord Hockemeyer cord.hockemeyer@uni-graz.at
Hockemeyer, C. (2001). KST Tools User Manual (2nd ed.). https://resources.cord-hockemeyer.info/techreports/KST-Tools_TechRep_FWF01.pdf.
Poetzi, S. & Wesiak, G. (2001). SRbT Tools User Manual. https://resources.cord-hockemeyer.info/techreports/SRBT-Tools_TechRep_FWF01.pdf
kstructure,
kstIO-package
# Obtain data to write from the 'pks' package
d <- getwd()
setwd(tempdir())
kst <-kmunionclosure(phsg$basis)
# Write structure to file
write_kstructure(kst, "phsg.struct") # Write in (default) SRBT format
# Write the matrix in CSV format
write_kstructure(kst, "phsg.csv")
setwd(d)
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.