| write_surmisefunction | R Documentation |
Write a surmise function to file
Write a attribution function to file
write_surmisefunction(x, filename, sep = ",")
write_attributionfunction(x, filename, sep = ",")
x |
Attribute function ( |
filename |
Name of the file to be written |
sep |
Cell separator for CSV files Attribute functions can only be stored in spreadsheet format. The concrete file format (CSV, ODS, or XLSX) is selected based on the filename extension. |
Other Functions for reading and writing surmise and attribution functions and relations:
read_surmisefunction(),
read_surmiserelation(),
write_surmiserelation()
kstMatrix::xpl$sf
tempfile <- paste0(tempdir(), "/test_sf.csv")
write_surmisefunction(kstMatrix::xpl$sf, tempfile)
cat(readLines(tempfile), sep='\n')
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.