write_surmisefunction: Write a surmise function file

write_surmisefunctionR Documentation

Write a surmise function file

Description

Write a surmise function to a file. The file formats are described in the kstIO-package information page.

Usage

  write_surmisefunction(x, filename, sep=',')

Arguments

x

The data to be written, either a quadratic binary matrix or an object of relation class.

filename

A character string specifying the name of the base file.

sep

Cell separator for CSAV files.

Details

Surmise function can (so far) be stored only in spreadsheet formats. The concrete file type (CSV, ODS, or XLSX) is determined from the filename extension.

Author(s)

Cord Hockemeyer cord.hockemeyer@uni-graz.at

See Also

kstIO-package


kstIO documentation built on March 8, 2026, 5:06 p.m.