| write_surmisefunction | R Documentation |
Write a surmise function to a file. The file formats are described in the kstIO-package information page.
write_surmisefunction(x, filename, sep=',')
x |
The data to be written, either a quadratic binary matrix or an object
of |
filename |
A character string specifying the name of the base file. |
sep |
Cell separator for CSAV files. |
Surmise function can (so far) be stored only in spreadsheet formats. The concrete file type (CSV, ODS, or XLSX) is determined from the filename extension.
Cord Hockemeyer cord.hockemeyer@uni-graz.at
kstIO-package
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.