| write_surmiserelation | R Documentation |
Write a surmise relation to a file. The file formats are described in the kstIO-package information page.
write_surmiserelation(x, filename, format = NULL, sep=',')
x |
The data to be written, either a quadratic binary matrix or an object
of |
filename |
A character string specifying the name of the relation file. |
format |
Specification of the files format. Can be "SRBT", "matrix",
CSV", "ODS", or "XLSX". If |
sep |
Cell separator for CSV files. |
The format values "SRBT" and
"matrix" refer to the different generations of file formats
described in kstIO-package. The other formats refer to the respective
spreadsheet formats.
Cord Hockemeyer cord.hockemeyer@uni-graz.at
Hockemeyer, C. (2001). KST Tools User Manual (2nd ed.). https://resources.cord-hockemeyer.info/techreports/KST-Tools_TechRep_FWF01.pdf.
Poetzi, S. & Wesiak, G. (2001). SRbT Tools User Manual. https://resources.cord-hockemeyer.info/techreports/SRBT-Tools_TechRep_FWF01.pdf
kstIO-package
d <- getwd()
setwd(tempdir())
r <- kmsurmiserelation(phsg$basis)
# Write surmise relation to file
write_surmiserelation(r, "phsg.bas") # Write in (default) SRBT format
write_surmiserelation(r, "phsg.ods") # ODS format
setwd(d)
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.